﻿using CQRSwithMediatR.Features.Commands;
using CQRSwithMediatR.Features.Queries;
using MediatR;
using Microsoft.AspNetCore.Mvc;
using System;
using System.Threading.Tasks;

namespace CQRSwithMediatR.Controllers
{
	[Route("api/[controller]")]
	[ApiController]
	public class BookController : ControllerBase
	{
		private readonly IMediator _mediator;

		public BookController(IMediator mediator)
		{
			_mediator = mediator ?? throw new ArgumentNullException(nameof(mediator));
		}

		// GET: api/<BookController>
		[HttpGet]
		public async Task<IActionResult> Get()
		{
			return Ok(await _mediator.Send(new GetAllBooksQuery()));
		}

		// GET:api/<BookController>/1
		[HttpGet]
		public async Task<IActionResult> GetBookById(int id)
		{
			return Ok(await _mediator.Send(new GetBookByIdQuery() { Id = id }));
		}

		// POST: api/<BookController>/1
		[HttpPost]
		public async Task<IActionResult> UpdateBook(CreateBookCommand command)
		{
			return Ok(await _mediator.Send(command));
		}

		// PUT: api/<BookController>/1
		[HttpPut("{id}")]
		public async Task<IActionResult> UpdateBookByUd(int id, UpdateBookCommand command)
		{
			if (id != command.Id)
			{
				return BadRequest();
			}
			return Ok(await _mediator.Send(command));
		}

		// DELETE: api/<BookController>/1
		[HttpDelete]
		public async Task<IActionResult> Delete(int id)
		{
			return Ok(await _mediator.Send(new DeleteBookCommand { Id = id }));
		}
	}
}
